==> 2205.0.tar.gz: o3de/Code/Tools/ProjectManager/project_manager_files.cmake <==
#
#
# Copyright (c) Contributors to the Open 3D Engine Project.
# For complete copyright and license terms please see the LICENSE at the root of this distribution.
#
# SPDX-License-Identifier: Apache-2.0 OR MIT
#
#

set(FILES
    Source/Application.h
    Source/Application.cpp
    Source/ProjectManagerDefs.h
    Source/ScreenDefs.h
    Source/ScreenFactory.h
    Source/ScreenFactory.cpp
    Source/ScreensCtrl.h
    Source/ScreensCtrl.cpp
    Source/ScreenWidget.h
    Source/EngineInfo.h
    Source/EngineInfo.cpp
    Source/FormLineEditWidget.h
    Source/FormLineEditWidget.cpp
    Source/FormBrowseEditWidget.h
    Source/FormBrowseEditWidget.cpp
    Source/FormFolderBrowseEditWidget.h
    Source/FormFolderBrowseEditWidget.cpp
    Source/FormImageBrowseEditWidget.h
    Source/FormImageBrowseEditWidget.cpp
    Source/GemsSubWidget.h
    Source/GemsSubWidget.cpp
    Source/DownloadController.h
    Source/DownloadController.cpp
    Source/DownloadWorker.h
    Source/DownloadWorker.cpp
    Source/PathValidator.h
    Source/PathValidator.cpp
    Source/ProjectManagerWindow.h
    Source/ProjectManagerWindow.cpp
    Source/ProjectTemplateInfo.h
    Source/ProjectTemplateInfo.cpp
    Source/PythonBindings.h
    Source/PythonBindings.cpp
    Source/PythonBindingsInterface.h
    Source/ProjectInfo.h
    Source/ProjectInfo.cpp
    Source/ProjectUtils.h
    Source/ProjectUtils.cpp
    Source/ProjectBuilderWorker.h
    Source/ProjectBuilderWorker.cpp
    Source/ProjectBuilderController.h
    Source/ProjectBuilderController.cpp
    Source/UpdateProjectSettingsScreen.h
    Source/UpdateProjectSettingsScreen.cpp
    Source/NewProjectSettingsScreen.h
    Source/NewProjectSettingsScreen.cpp
    Source/CreateProjectCtrl.h
    Source/CreateProjectCtrl.cpp
    Source/UpdateProjectCtrl.h
    Source/UpdateProjectCtrl.cpp
    Source/ProjectsScreen.h
    Source/ProjectsScreen.cpp
    Source/ProjectSettingsScreen.h
    Source/ProjectSettingsScreen.cpp
    Source/EngineScreenCtrl.h
    Source/EngineScreenCtrl.cpp
    Source/EngineSettingsScreen.h
    Source/EngineSettingsScreen.cpp
    Source/ProjectButtonWidget.h
    Source/ProjectButtonWidget.cpp
    Source/ScreenHeaderWidget.h
    Source/ScreenHeaderWidget.cpp
    Source/Settings.h
    Source/Settings.cpp
    Source/SettingsInterface.h
    Source/LinkWidget.h
    Source/LinkWidget.cpp
    Source/TagWidget.h
    Source/TagWidget.cpp
    Source/TemplateButtonWidget.h
    Source/TemplateButtonWidget.cpp
    Source/ExternalLinkDialog.h
    Source/ExternalLinkDialog.cpp
    Source/AdjustableHeaderWidget.h
    Source/AdjustableHeaderWidget.cpp
    Source/GemCatalog/GemCatalogHeaderWidget.h
    Source/GemCatalog/GemCatalogHeaderWidget.cpp
    Source/GemCatalog/GemCatalogScreen.h
    Source/GemCatalog/GemCatalogScreen.cpp
    Source/GemCatalog/GemFilterTagWidget.h
    Source/GemCatalog/GemFilterTagWidget.cpp
    Source/GemCatalog/GemFilterWidget.h
    Source/GemCatalog/GemFilterWidget.cpp
    Source/GemCatalog/GemInfo.h
    Source/GemCatalog/GemInfo.cpp
    Source/GemCatalog/GemInspector.h
    Source/GemCatalog/GemInspector.cpp
    Source/GemCatalog/GemItemDelegate.h
    Source/GemCatalog/GemItemDelegate.cpp
    Source/GemCatalog/GemListView.h
    Source/GemCatalog/GemListView.cpp
    Source/GemCatalog/GemListHeaderWidget.h
    Source/GemCatalog/GemListHeaderWidget.cpp
    Source/GemCatalog/GemModel.h
    Source/GemCatalog/GemModel.cpp
    Source/GemCatalog/GemUninstallDialog.h
    Source/GemCatalog/GemUninstallDialog.cpp
    Source/GemCatalog/GemUpdateDialog.h
    Source/GemCatalog/GemUpdateDialog.cpp
    Source/GemCatalog/GemDependenciesDialog.h
    Source/GemCatalog/GemDependenciesDialog.cpp
    Source/GemCatalog/GemRequirementDialog.h
    Source/GemCatalog/GemRequirementDialog.cpp
    Source/GemCatalog/GemRequirementDelegate.h
    Source/GemCatalog/GemRequirementDelegate.cpp
    Source/GemCatalog/GemRequirementFilterProxyModel.h
    Source/GemCatalog/GemRequirementFilterProxyModel.cpp
    Source/GemCatalog/GemRequirementListView.h
    Source/GemCatalog/GemRequirementListView.cpp
    Source/GemCatalog/GemSortFilterProxyModel.h
    Source/GemCatalog/GemSortFilterProxyModel.cpp
    Source/GemRepo/GemRepoScreen.h
    Source/GemRepo/GemRepoScreen.cpp
    Source/GemRepo/GemRepoAddDialog.h
    Source/GemRepo/GemRepoAddDialog.cpp
    Source/GemRepo/GemRepoInfo.h
    Source/GemRepo/GemRepoInfo.cpp
    Source/GemRepo/GemRepoInspector.h
    Source/GemRepo/GemRepoInspector.cpp
    Source/GemRepo/GemRepoItemDelegate.h
    Source/GemRepo/GemRepoItemDelegate.cpp
    Source/GemRepo/GemRepoListView.h
    Source/GemRepo/GemRepoListView.cpp
    Source/GemRepo/GemRepoModel.h
    Source/GemRepo/GemRepoModel.cpp
)

==> 2210.0.tar.gz: o3de/Code/Tools/ProjectManager/project_manager_files.cmake <==
#
#
# Copyright (c) Contributors to the Open 3D Engine Project.
# For complete copyright and license terms please see the LICENSE at the root of this distribution.
#
# SPDX-License-Identifier: Apache-2.0 OR MIT
#
#

set(FILES
    Source/Application.h
    Source/Application.cpp
    Source/ProjectManagerDefs.h
    Source/ScreenDefs.h
    Source/ScreenFactory.h
    Source/ScreenFactory.cpp
    Source/ScreensCtrl.h
    Source/ScreensCtrl.cpp
    Source/ScreenWidget.h
    Source/EngineInfo.h
    Source/EngineInfo.cpp
    Source/FormLineEditWidget.h
    Source/FormLineEditWidget.cpp
    Source/FormBrowseEditWidget.h
    Source/FormBrowseEditWidget.cpp
    Source/FormComboBoxWidget.h
    Source/FormComboBoxWidget.cpp
    Source/FormFolderBrowseEditWidget.h
    Source/FormFolderBrowseEditWidget.cpp
    Source/FormImageBrowseEditWidget.h
    Source/FormImageBrowseEditWidget.cpp
    Source/GemsGemRepoScreen.h
    Source/GemsGemRepoScreen.cpp
    Source/GemsSubWidget.h
    Source/GemsSubWidget.cpp
    Source/DownloadController.h
    Source/DownloadController.cpp
    Source/DownloadWorker.h
    Source/DownloadWorker.cpp
    Source/PathValidator.h
    Source/PathValidator.cpp
    Source/ProjectManagerWindow.h
    Source/ProjectManagerWindow.cpp
    Source/ProjectTemplateInfo.h
    Source/ProjectGemCatalogScreen.h
    Source/ProjectGemCatalogScreen.cpp
    Source/PythonBindings.h
    Source/PythonBindings.cpp
    Source/PythonBindingsInterface.h
    Source/ProjectInfo.h
    Source/ProjectInfo.cpp
    Source/ProjectUtils.h
    Source/ProjectUtils.cpp
    Source/ProjectBuilderWorker.h
    Source/ProjectBuilderWorker.cpp
    Source/ProjectBuilderController.h
    Source/ProjectBuilderController.cpp
    Source/UpdateProjectSettingsScreen.h
    Source/UpdateProjectSettingsScreen.cpp
    Source/NewProjectSettingsScreen.h
    Source/NewProjectSettingsScreen.cpp
    Source/CreateProjectCtrl.h
    Source/CreateProjectCtrl.cpp
    Source/UpdateProjectCtrl.h
    Source/UpdateProjectCtrl.cpp
    Source/ProjectsScreen.h
    Source/ProjectsScreen.cpp
    Source/ProjectSettingsScreen.h
    Source/ProjectSettingsScreen.cpp
    Source/EngineScreenCtrl.h
    Source/EngineScreenCtrl.cpp
    Source/EngineSettingsScreen.h
    Source/EngineSettingsScreen.cpp
    Source/ProjectButtonWidget.h
    Source/ProjectButtonWidget.cpp
    Source/ScreenHeaderWidget.h
    Source/ScreenHeaderWidget.cpp
    Source/Settings.h
    Source/Settings.cpp
    Source/SettingsInterface.h
    Source/LinkWidget.h
    Source/LinkWidget.cpp
    Source/TagWidget.h
    Source/TagWidget.cpp
    Source/TemplateButtonWidget.h
    Source/TemplateButtonWidget.cpp
    Source/TemplateInfo.cpp
    Source/TemplateInfo.h
    Source/ExternalLinkDialog.h
    Source/ExternalLinkDialog.cpp
    Source/AdjustableHeaderWidget.h
    Source/AdjustableHeaderWidget.cpp
    Source/AddRemoteProjectDialog.h
    Source/AddRemoteProjectDialog.cpp
    Source/AddRemoteTemplateDialog.h
    Source/AddRemoteTemplateDialog.cpp
    Source/DownloadRemoteTemplateDialog.h
    Source/DownloadRemoteTemplateDialog.cpp
    Source/TextOverflowWidget.h
    Source/TextOverflowWidget.cpp
    Source/CreateAGemScreen.h
    Source/CreateAGemScreen.cpp
    Source/GemCatalog/GemCatalogHeaderWidget.h
    Source/GemCatalog/GemCatalogHeaderWidget.cpp
    Source/GemCatalog/GemCatalogScreen.h
    Source/GemCatalog/GemCatalogScreen.cpp
    Source/GemCatalog/GemFilterTagWidget.h
    Source/GemCatalog/GemFilterTagWidget.cpp
    Source/GemCatalog/GemFilterWidget.h
    Source/GemCatalog/GemFilterWidget.cpp
    Source/GemCatalog/GemInfo.h
    Source/GemCatalog/GemInfo.cpp
    Source/GemCatalog/GemInspector.h
    Source/GemCatalog/GemInspector.cpp
    Source/GemCatalog/GemItemDelegate.h
    Source/GemCatalog/GemItemDelegate.cpp
    Source/GemCatalog/GemListView.h
    Source/GemCatalog/GemListView.cpp
    Source/GemCatalog/GemListHeaderWidget.h
    Source/GemCatalog/GemListHeaderWidget.cpp
    Source/GemCatalog/GemModel.h
    Source/GemCatalog/GemModel.cpp
    Source/GemCatalog/GemUninstallDialog.h
    Source/GemCatalog/GemUninstallDialog.cpp
    Source/GemCatalog/GemUpdateDialog.h
    Source/GemCatalog/GemUpdateDialog.cpp
    Source/GemCatalog/GemDependenciesDialog.h
    Source/GemCatalog/GemDependenciesDialog.cpp
    Source/GemCatalog/GemRequirementDialog.h
    Source/GemCatalog/GemRequirementDialog.cpp
    Source/GemCatalog/GemRequirementDelegate.h
    Source/GemCatalog/GemRequirementDelegate.cpp
    Source/GemCatalog/GemRequirementFilterProxyModel.h
    Source/GemCatalog/GemRequirementFilterProxyModel.cpp
    Source/GemCatalog/GemRequirementListView.h
    Source/GemCatalog/GemRequirementListView.cpp
    Source/GemCatalog/GemSortFilterProxyModel.h
    Source/GemCatalog/GemSortFilterProxyModel.cpp
    Source/GemRepo/GemRepoScreen.h
    Source/GemRepo/GemRepoScreen.cpp
    Source/GemRepo/GemRepoAddDialog.h
    Source/GemRepo/GemRepoAddDialog.cpp
    Source/GemRepo/GemRepoInfo.h
    Source/GemRepo/GemRepoInfo.cpp
    Source/GemRepo/GemRepoInspector.h
    Source/GemRepo/GemRepoInspector.cpp
    Source/GemRepo/GemRepoItemDelegate.h
    Source/GemRepo/GemRepoItemDelegate.cpp
    Source/GemRepo/GemRepoListView.h
    Source/GemRepo/GemRepoListView.cpp
    Source/GemRepo/GemRepoModel.h
    Source/GemRepo/GemRepoModel.cpp
)
